Description Usage Format Source See Also
A dataset made from combining 'pbp_matches_atp_main_current.csv' and 'pbp_matches_atp_main_archive' by Jeff Sackmann. Contains point-by-point records of ATP tennis matches from 2011 to 2017.
1 |
A data frame with 13050 rows and 12 variables:
unique identifier of a tennis match
date of match, format: DD MON YY
tournament name
name of tour, i.e., ATP
draw, i.e., Main
name of player who served first, often referred to as player1
name of opponent of server1, often referred to as player2
winner of match, i.e., 1 or 2, corresponding to one of the previous two columns
point-by-point record; S (server won), R (returner won), A (ace), D (double fault); Sets are delimited with the '.' character, games are delimited with the ';' character, and the '/' character indicates changes of serve during a tiebreak
final score of match
1 if the point sequence notes any aces or double faults, 0 if not
...
https://github.com/JeffSackmann/tennis_pointbypoint
pbp_raw_clean.df for cleaned version
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.